@@ -14,8 +14,10 @@ public:
 
 	Q_INVOKABLE void setCompaniesFollowed(QString xml);
 	Q_INVOKABLE bool following(QString id);
+	Q_INVOKABLE int numFollowing();
 	Q_INVOKABLE void follow(QString id, QString name);
 	Q_INVOKABLE void stopFollow(QString id);
+	Q_INVOKABLE QString getCompanyQuery();
 
 	Q_INVOKABLE void setPeopleConnections(QString xml);
 	Q_INVOKABLE bool connected(QString id);
